@@ -58,6 +58,7 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Map.Entry;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.id.IDGeneratorService;
@@ -82,7 +83,7 @@ public class OAuthCopyTask implements CopyUserTaskService {
     private static final String SELECT_ACCOUNTS =
         "SELECT " +
             "id, displayName, accessToken, accessSecret, " +
-            "serviceId FROM oauthAccounts " +
+            "serviceId, scope FROM oauthAccounts " +
         "WHERE " +
             "cid = ? " +
         "AND " +
@@ -91,9 +92,9 @@ public class OAuthCopyTask implements CopyUserTaskService {
     private static final String INSERT_ACCOUNTS =
         "INSERT INTO " +
             "oauthAccounts " +
-            "(cid, user, id, displayName, accessToken, accessSecret, serviceId) " +
+            "(cid, user, id, displayName, accessToken, accessSecret, serviceId, scope) " +
         "VALUES " +
-            "(?, ?, ?, ?, ?, ?, ?)";
+            "(?, ?, ?, ?, ?, ?, ?, ?)";
 
     private final IDGeneratorService idService;
 
@@ -145,8 +146,9 @@ public class OAuthCopyTask implements CopyUserTaskService {
                 final Map<Integer, Integer> oAuthMapping = exchangeOAuthIds(dstCon, accounts, dstCtx);
                 writeOAuthAccountsToDB(accounts, dstCon, i(dstCtxId), i(dstUsrId));
 
-                for (final Integer origin : oAuthMapping.keySet()) {
-                    final Integer target = oAuthMapping.get(origin);
+                for (final Entry<Integer, Integer> entry : oAuthMapping.entrySet()) {
+                    Integer origin = entry.getKey();
+                    Integer target = entry.getValue();
                     accountMapping.addMapping(origin, target);
                 }
             }
@@ -165,7 +167,7 @@ public class OAuthCopyTask implements CopyUserTaskService {
     }
 
     public Map<Integer, Integer> exchangeOAuthIds(final Connection con, final List<OAuthAccount> accounts, final Context ctx) throws OXException {
-        final Map<Integer, Integer> mapping = new HashMap<Integer, Integer>();
+        final Map<Integer, Integer> mapping = new HashMap<>();
         for (final OAuthAccount account : accounts) {
             try {
                 final int oldId = account.getId();
@@ -182,7 +184,7 @@ public class OAuthCopyTask implements CopyUserTaskService {
     }
 
     List<OAuthAccount> loadOAuthAccountsFromDB(final Connection con, final int uid, final int cid) throws OXException {
-        final List<OAuthAccount> accounts = new ArrayList<OAuthAccount>();
+        final List<OAuthAccount> accounts = new ArrayList<>();
         PreparedStatement stmt = null;
         ResultSet rs = null;
         try {
@@ -199,7 +201,7 @@ public class OAuthCopyTask implements CopyUserTaskService {
                 account.setAccessToken(rs.getString(i++));
                 account.setAccessSecret(rs.getString(i++));
                 account.setServiceId(rs.getString(i++));
-
+                account.setScope(rs.getString(i++));
                 accounts.add(account);
             }
         } catch (final SQLException e) {
@@ -224,7 +226,7 @@ public class OAuthCopyTask implements CopyUserTaskService {
                 stmt.setString(i++, account.getAccessToken());
                 stmt.setString(i++, account.getAccessSecret());
                 stmt.setString(i++, account.getServiceId());
-
+                stmt.setString(i++, account.getScope());
                 stmt.addBatch();
             }
 
